@@ -7,9 +7,9 @@ from dataclasses import dataclass
 from collections import namedtuple
 from voluptuous import Schema
 from inform import plural
+from more_itertools import flatten
 from stringcase import snakecase, sentencecase
 from mergedeep import merge
-from Bio.Seq import Seq
 from Bio.SeqUtils import MeltingTemp, molecular_weight
 from .config import Config, load_config
 from .errors import LoadError, QueryError, CheckError
@@ -107,6 +107,12 @@ class Reagent:
 
         return f'{self.__class__.__qualname__}({", ".join(attr_strs)})'
 
+    def __eq__(self, other):
+        return self.db is other.db and self.tag == other.tag
+
+    def __hash__(self):
+        return hash((id(self.db), self.tag))
+
     def check(self):
         pass
 
@@ -282,6 +288,10 @@ class Reagent:
 @autoprop.immutable
 class Strain(Reagent):
 
+    def get_parent_strain(self):
+        # Right now this is just a string.  But maybe it should be an object...
+        return self._attrs.get('parent_strain')
+
     def get_plasmids(self):
         plasmids = self._attrs.get('plasmids', [])
 
@@ -290,6 +300,20 @@ class Strain(Reagent):
 
         return plasmids
 
+    def get_antibiotics(self):
+        antibiotics = self._attrs.get('antibiotics', [])
+
+        if callable(antibiotics):
+            antibiotics = antibiotics()
+
+        if not antibiotics:
+            antibiotics = list(flatten(
+                x.antibiotics
+                for x in self.plasmids
+            ))
+
+        return antibiotics
+
 
 @autoprop.immutable
 class Buffer(Reagent):
@@ -599,7 +623,7 @@ class Plasmid(NucleicAcid):
         *resistance* argument to the constructor, or inferred by comparing the 
         list of features in the config file to the sequence of the plasmid.
         """
-        resistance = self._attrs.get('resistance', [])
+        resistance = self._attrs.get('resistance')
 
         if not resistance:
             resistance = self._find_features('resistance')
@@ -609,6 +633,27 @@ class Plasmid(NucleicAcid):
 
         return resistance
 
+    def get_antibiotics(self):
+
+        def strip_r(x):
+            return x[:-1] if x.endswith('R') else x
+
+        antibiotics = self._attrs.get('antibiotics')
+
+        if callable(antibiotics):
+            antibiotics = antibiotics()
+
+        if not antibiotics:
+            try:
+                antibiotics = [strip_r(x) for x in self.resistance]
+            except QueryError:
+                pass
+
+        if not antibiotics:
+            raise QueryError("no antibiotics specified", culprit=self)
+
+        return antibiotics
+
     @property
     def is_double_stranded(self):
         return True
@@ -621,7 +666,7 @@ class Plasmid(NucleicAcid):
         hits = []
 
         try:
-            plasmid_seq = Seq(self.seq.upper())
+            plasmid_seq = self.seq
         except QueryError:
             return []
 
@@ -630,7 +675,7 @@ class Plasmid(NucleicAcid):
         for feat in features:
             try:
                 feat_name = feat['name']
-                feat_seq = feat['seq'].upper()
+                feat_seq = feat['seq']
                 feat_role = feat['role']
             except KeyError as err1:
                 err2 = QueryError(db=self.db, feature=feat, key=err1.args[0])
@@ -642,17 +687,12 @@ class Plasmid(NucleicAcid):
             if role and feat_role != role:
                 continue
 
-            # Checking for an exact substring match.  In the future, 
-            # I'd like to relax this, e.g. do a sequence alignment and 
-            # check for a certain percent identity.  I'd also like to 
-            # allow protein sequences to be specified.
+            # This will fail if the resistance gene spans the ends of the 
+            # plasmid sequence string.  But I'll wait to worry about that until 
+            # I write a more comprehensive sequence manipulation module.
 
-            # This will also fail if the resistance gene spans the ends 
-            # of the plasmid sequence string.  But I'll wait to worry 
-            # about that until I write a more comprehensive sequence 
-            # manipulation module.
-            if feat_seq in plasmid_seq or \
-                    feat_seq in plasmid_seq.reverse_complement():
+            identity = calc_sequence_identity_with_rc(feat_seq, plasmid_seq)
+            if identity > feat.get('identity_threshold', 0.95):
                 hits.append(feat_name)
 
         return hits
@@ -702,6 +742,15 @@ class MakerInterface:
 
     @property
     def dependencies(self):
+        """
+        Return a iterable containing all the tags that this maker depends on.
+        
+        Most implementations return a set, since that is the most appropriate 
+        data structure semantically, but any iterable is acceptable.  For 
+        instance, in some cases it might be more convenient to write this 
+        method as a generator (e.g. to yield dependencies).  Any duplicates in 
+        the iterable will be ignored.
+        """
         raise AttributeError
 
     @property
